@@ -5,7 +5,7 @@
 #    This source file contains the public functions.
 #    The others are contained in "plotpriv.tcl"
 #
-package require Tcl 8.3
+package require Tcl 8.4
 package require Tk
 
 # Plotchart --
@@ -30,195 +30,220 @@ namespace eval ::Plotchart {
                     createGanttChart createHistogram colorMap \
                     create3DBars createRadialchart \
                     createTXPlot createRightAxis \
-                    create3DRibbonChart
+                    create3DRibbonChart \
+                    createXLogYPlot \
+                    plotconfig plotpack \
 
    #
    # Array linking procedures with methods
    #
-   set methodProc(xyplot,title)          DrawTitle
-   set methodProc(xyplot,xtext)          DrawXtext
-   set methodProc(xyplot,ytext)          DrawYtext
-   set methodProc(xyplot,plot)           DrawData
-   set methodProc(xyplot,dot)            DrawDot
-   set methodProc(xyplot,dotconfig)      DotConfigure
-   set methodProc(xyplot,interval)       DrawInterval
-   set methodProc(xyplot,trend)          DrawTrendLine
-   set methodProc(xyplot,vector)         DrawVector
-   set methodProc(xyplot,vectorconfig)   VectorConfigure
-   set methodProc(xyplot,rchart)         DrawRchart
-   set methodProc(xyplot,grid)           DrawGrid
-   set methodProc(xyplot,contourlines)   DrawIsolines
-   set methodProc(xyplot,contourfill)    DrawShades
-   set methodProc(xyplot,contourbox)     DrawBox
-   set methodProc(xyplot,saveplot)       SavePlot
-   set methodProc(xyplot,dataconfig)     DataConfig
-   set methodProc(xyplot,xconfig)        XConfig
-   set methodProc(xyplot,yconfig)        YConfig
-   set methodProc(xyplot,xticklines)     DrawXTicklines
-   set methodProc(xyplot,yticklines)     DrawYTicklines
-   set methodProc(xyplot,background)     BackgroundColour
-   set methodProc(xyplot,legendconfig)   LegendConfigure
-   set methodProc(xyplot,legend)         DrawLegend
-   set methodProc(xyplot,balloon)        DrawBalloon
-   set methodProc(xyplot,balloonconfig)  ConfigBalloon
-   set methodProc(xyplot,plaintext)      DrawPlainText
-   set methodProc(piechart,title)        DrawTitle
-   set methodProc(piechart,plot)         DrawPie
-   set methodProc(piechart,saveplot)     SavePlot
-   set methodProc(piechart,balloon)      DrawBalloon
-   set methodProc(piechart,balloonconfig) ConfigBalloon
-   set methodProc(piechart,plaintext)    DrawPlainText
-   set methodProc(polarplot,title)       DrawTitle
-   set methodProc(polarplot,plot)        DrawPolarData
-   set methodProc(polarplot,saveplot)    SavePlot
-   set methodProc(polarplot,dataconfig)  DataConfig
-   set methodProc(polarplot,background)  BackgroundColour
-   set methodProc(polarplot,legendconfig) LegendConfigure
-   set methodProc(polarplot,legend)      DrawLegend
-   set methodProc(polarplot,balloon)     DrawBalloon
-   set methodProc(polarplot,balloonconfig) ConfigBalloon
-   set methodProc(polarplot,plaintext)   DrawPlainText
-   set methodProc(histogram,title)       DrawTitle
-   set methodProc(histogram,xtext)       DrawXtext
-   set methodProc(histogram,ytext)       DrawYtext
-   set methodProc(histogram,plot)        DrawHistogramData
-   set methodProc(histogram,saveplot)    SavePlot
-   set methodProc(histogram,dataconfig)  DataConfig
-   set methodProc(histogram,xconfig)     XConfig
-   set methodProc(histogram,yconfig)     YConfig
-   set methodProc(histogram,yticklines)  DrawYTicklines
-   set methodProc(histogram,background)  BackgroundColour
-   set methodProc(histogram,legendconfig) LegendConfigure
-   set methodProc(histogram,legend)      DrawLegend
-   set methodProc(histogram,balloon)     DrawBalloon
-   set methodProc(histogram,balloonconfig) ConfigBalloon
-   set methodProc(histogram,plaintext)   DrawPlainText
-   set methodProc(horizbars,title)       DrawTitle
-   set methodProc(horizbars,xtext)       DrawXtext
-   set methodProc(horizbars,ytext)       DrawYtext
-   set methodProc(horizbars,plot)        DrawHorizBarData
-   set methodProc(horizbars,xticklines)  DrawXTicklines
-   set methodProc(horizbars,background)  BackgroundColour
-   set methodProc(horizbars,saveplot)    SavePlot
-   set methodProc(horizbars,colours)     SetColours
-   set methodProc(horizbars,colors)      SetColours
-   set methodProc(horizbars,xconfig)     XConfig
-   set methodProc(horizbars,legendconfig) LegendConfigure
-   set methodProc(horizbars,legend)      DrawLegend
-   set methodProc(horizbars,balloon)     DrawBalloon
-   set methodProc(horizbars,balloonconfig) ConfigBalloon
-   set methodProc(horizbars,plaintext)   DrawPlainText
-   set methodProc(vertbars,title)        DrawTitle
-   set methodProc(vertbars,xtext)        DrawXtext
-   set methodProc(vertbars,ytext)        DrawYtext
-   set methodProc(vertbars,plot)         DrawVertBarData
-   set methodProc(vertbars,background)   BackgroundColour
-   set methodProc(vertbars,yticklines)   DrawYTicklines
-   set methodProc(vertbars,saveplot)     SavePlot
-   set methodProc(vertbars,colours)      SetColours
-   set methodProc(vertbars,colors)       SetColours
-   set methodProc(vertbars,yconfig)      YConfig
-   set methodProc(vertbars,legendconfig) LegendConfigure
-   set methodProc(vertbars,legend)       DrawLegend
-   set methodProc(vertbars,balloon)      DrawBalloon
-   set methodProc(vertbars,balloonconfig) ConfigBalloon
-   set methodProc(vertbars,plaintext)    DrawPlainText
-   set methodProc(timechart,title)       DrawTitle
-   set methodProc(timechart,period)      DrawTimePeriod
-   set methodProc(timechart,milestone)   DrawTimeMilestone
-   set methodProc(timechart,vertline)    DrawTimeVertLine
-   set methodProc(timechart,saveplot)    SavePlot
-   set methodProc(timechart,background)  BackgroundColour
-   set methodProc(timechart,balloon)     DrawBalloon
-   set methodProc(timechart,balloonconfig) ConfigBalloon
-   set methodProc(timechart,plaintext)   DrawPlainText
-   set methodProc(ganttchart,title)      DrawTitle
-   set methodProc(ganttchart,period)     DrawGanttPeriod
-   set methodProc(ganttchart,task)       DrawGanttPeriod
-   set methodProc(ganttchart,milestone)  DrawGanttMilestone
-   set methodProc(ganttchart,vertline)   DrawGanttVertLine
-   set methodProc(ganttchart,saveplot)   SavePlot
-   set methodProc(ganttchart,color)      GanttColor
-   set methodProc(ganttchart,colour)     GanttColor
-   set methodProc(ganttchart,font)       GanttFont
-   set methodProc(ganttchart,connect)    DrawGanttConnect
-   set methodProc(ganttchart,summary)    DrawGanttSummary
-   set methodProc(ganttchart,background) BackgroundColour
-   set methodProc(ganttchart,balloon)     DrawBalloon
+   set methodProc(xyplot,title)             DrawTitle
+   set methodProc(xyplot,xtext)             DrawXtext
+   set methodProc(xyplot,ytext)             DrawYtext
+   set methodProc(xyplot,plot)              DrawData
+   set methodProc(xyplot,dot)               DrawDot
+   set methodProc(xyplot,dotconfig)         DotConfigure
+   set methodProc(xyplot,interval)          DrawInterval
+   set methodProc(xyplot,trend)             DrawTrendLine
+   set methodProc(xyplot,vector)            DrawVector
+   set methodProc(xyplot,vectorconfig)      VectorConfigure
+   set methodProc(xyplot,rchart)            DrawRchart
+   set methodProc(xyplot,grid)              DrawGrid
+   set methodProc(xyplot,contourlines)      DrawIsolines
+   set methodProc(xyplot,contourfill)       DrawShades
+   set methodProc(xyplot,contourbox)        DrawBox
+   set methodProc(xyplot,saveplot)          SavePlot
+   set methodProc(xyplot,dataconfig)        DataConfig
+   set methodProc(xyplot,xconfig)           XConfig
+   set methodProc(xyplot,yconfig)           YConfig
+   set methodProc(xyplot,xticklines)        DrawXTicklines
+   set methodProc(xyplot,yticklines)        DrawYTicklines
+   set methodProc(xyplot,background)        BackgroundColour
+   set methodProc(xyplot,legendconfig)      LegendConfigure
+   set methodProc(xyplot,legend)            DrawLegend
+   set methodProc(xyplot,balloon)           DrawBalloon
+   set methodProc(xyplot,balloonconfig)     ConfigBalloon
+   set methodProc(xyplot,plaintext)         DrawPlainText
+   set methodProc(xyplot,bindvar)           BindVar
+   set methodProc(xyplot,bindcmd)           BindCmd
+   set methodProc(xyplot,rescale)           RescalePlot
+   set methodProc(xlogyplot,title)          DrawTitle
+   set methodProc(xlogyplot,xtext)          DrawXtext
+   set methodProc(xlogyplot,ytext)          DrawYtext
+   set methodProc(xlogyplot,plot)           DrawLogData
+   set methodProc(xlogyplot,dot)            DrawLogDot
+   set methodProc(xlogyplot,dotconfig)      DotConfigure
+   set methodProc(xlogyplot,interval)       DrawLogInterval
+   set methodProc(xlogyplot,trend)          DrawLogTrendLine
+   set methodProc(xlogyplot,saveplot)       SavePlot
+   set methodProc(xlogyplot,dataconfig)     DataConfig
+   set methodProc(xlogyplot,xconfig)        XConfig
+   set methodProc(xlogyplot,yconfig)        YConfig
+   set methodProc(xlogyplot,xticklines)     DrawXTicklines
+   set methodProc(xlogyplot,yticklines)     DrawYTicklines
+   set methodProc(xlogyplot,background)     BackgroundColour
+   set methodProc(xlogyplot,legendconfig)   LegendConfigure
+   set methodProc(xlogyplot,legend)         DrawLegend
+   set methodProc(xlogyplot,balloon)        DrawBalloon
+   set methodProc(xlogyplot,balloonconfig)  ConfigBalloon
+   set methodProc(xlogyplot,plaintext)      DrawPlainText
+   set methodProc(piechart,title)           DrawTitle
+   set methodProc(piechart,plot)            DrawPie
+   set methodProc(piechart,saveplot)        SavePlot
+   set methodProc(piechart,balloon)         DrawBalloon
+   set methodProc(piechart,balloonconfig)   ConfigBalloon
+   set methodProc(piechart,plaintext)       DrawPlainText
+   set methodProc(polarplot,title)          DrawTitle
+   set methodProc(polarplot,plot)           DrawPolarData
+   set methodProc(polarplot,saveplot)       SavePlot
+   set methodProc(polarplot,dataconfig)     DataConfig
+   set methodProc(polarplot,background)     BackgroundColour
+   set methodProc(polarplot,legendconfig)   LegendConfigure
+   set methodProc(polarplot,legend)         DrawLegend
+   set methodProc(polarplot,balloon)        DrawBalloon
+   set methodProc(polarplot,balloonconfig)  ConfigBalloon
+   set methodProc(polarplot,plaintext)      DrawPlainText
+   set methodProc(histogram,title)          DrawTitle
+   set methodProc(histogram,xtext)          DrawXtext
+   set methodProc(histogram,ytext)          DrawYtext
+   set methodProc(histogram,plot)           DrawHistogramData
+   set methodProc(histogram,saveplot)       SavePlot
+   set methodProc(histogram,dataconfig)     DataConfig
+   set methodProc(histogram,xconfig)        XConfig
+   set methodProc(histogram,yconfig)        YConfig
+   set methodProc(histogram,yticklines)     DrawYTicklines
+   set methodProc(histogram,background)     BackgroundColour
+   set methodProc(histogram,legendconfig)   LegendConfigure
+   set methodProc(histogram,legend)         DrawLegend
+   set methodProc(histogram,balloon)        DrawBalloon
+   set methodProc(histogram,balloonconfig)  ConfigBalloon
+   set methodProc(histogram,plaintext)      DrawPlainText
+   set methodProc(horizbars,title)          DrawTitle
+   set methodProc(horizbars,xtext)          DrawXtext
+   set methodProc(horizbars,ytext)          DrawYtext
+   set methodProc(horizbars,plot)           DrawHorizBarData
+   set methodProc(horizbars,xticklines)     DrawXTicklines
+   set methodProc(horizbars,background)     BackgroundColour
+   set methodProc(horizbars,saveplot)       SavePlot
+   set methodProc(horizbars,colours)        SetColours
+   set methodProc(horizbars,colors)         SetColours
+   set methodProc(horizbars,xconfig)        XConfig
+   set methodProc(horizbars,legendconfig)   LegendConfigure
+   set methodProc(horizbars,legend)         DrawLegend
+   set methodProc(horizbars,balloon)        DrawBalloon
+   set methodProc(horizbars,balloonconfig)  ConfigBalloon
+   set methodProc(horizbars,plaintext)      DrawPlainText
+   set methodProc(vertbars,title)           DrawTitle
+   set methodProc(vertbars,xtext)           DrawXtext
+   set methodProc(vertbars,ytext)           DrawYtext
+   set methodProc(vertbars,plot)            DrawVertBarData
+   set methodProc(vertbars,background)      BackgroundColour
+   set methodProc(vertbars,yticklines)      DrawYTicklines
+   set methodProc(vertbars,saveplot)        SavePlot
+   set methodProc(vertbars,colours)         SetColours
+   set methodProc(vertbars,colors)          SetColours
+   set methodProc(vertbars,yconfig)         YConfig
+   set methodProc(vertbars,legendconfig)    LegendConfigure
+   set methodProc(vertbars,legend)          DrawLegend
+   set methodProc(vertbars,balloon)         DrawBalloon
+   set methodProc(vertbars,balloonconfig)   ConfigBalloon
+   set methodProc(vertbars,plaintext)       DrawPlainText
+   set methodProc(timechart,title)          DrawTitle
+   set methodProc(timechart,period)         DrawTimePeriod
+   set methodProc(timechart,milestone)      DrawTimeMilestone
+   set methodProc(timechart,vertline)       DrawTimeVertLine
+   set methodProc(timechart,saveplot)       SavePlot
+   set methodProc(timechart,background)     BackgroundColour
+   set methodProc(timechart,balloon)        DrawBalloon
+   set methodProc(timechart,balloonconfig)  ConfigBalloon
+   set methodProc(timechart,plaintext)      DrawPlainText
+   set methodProc(ganttchart,title)         DrawTitle
+   set methodProc(ganttchart,period)        DrawGanttPeriod
+   set methodProc(ganttchart,task)          DrawGanttPeriod
+   set methodProc(ganttchart,milestone)     DrawGanttMilestone
+   set methodProc(ganttchart,vertline)      DrawGanttVertLine
+   set methodProc(ganttchart,saveplot)      SavePlot
+   set methodProc(ganttchart,color)         GanttColor
+   set methodProc(ganttchart,colour)        GanttColor
+   set methodProc(ganttchart,font)          GanttFont
+   set methodProc(ganttchart,connect)       DrawGanttConnect
+   set methodProc(ganttchart,summary)       DrawGanttSummary
+   set methodProc(ganttchart,background)    BackgroundColour
+   set methodProc(ganttchart,balloon)       DrawBalloon
    set methodProc(ganttchart,balloonconfig) ConfigBalloon
-   set methodProc(ganttchart,plaintext)  DrawPlainText
-   set methodProc(stripchart,title)      DrawTitle
-   set methodProc(stripchart,xtext)      DrawXtext
-   set methodProc(stripchart,ytext)      DrawYtext
-   set methodProc(stripchart,plot)       DrawStripData
-   set methodProc(stripchart,saveplot)   SavePlot
-   set methodProc(stripchart,dataconfig) DataConfig
-   set methodProc(stripchart,xconfig)    XConfig
-   set methodProc(stripchart,yconfig)    YConfig
-   set methodProc(stripchart,yticklines) DrawYTicklines
-   set methodProc(stripchart,background) BackgroundColour
-   set methodProc(stripchart,legendconfig) LegendConfigure
-   set methodProc(stripchart,legend)     DrawLegend
-   set methodProc(stripchart,balloon)    DrawBalloon
+   set methodProc(ganttchart,plaintext)     DrawPlainText
+   set methodProc(stripchart,title)         DrawTitle
+   set methodProc(stripchart,xtext)         DrawXtext
+   set methodProc(stripchart,ytext)         DrawYtext
+   set methodProc(stripchart,plot)          DrawStripData
+   set methodProc(stripchart,saveplot)      SavePlot
+   set methodProc(stripchart,dataconfig)    DataConfig
+   set methodProc(stripchart,xconfig)       XConfig
+   set methodProc(stripchart,yconfig)       YConfig
+   set methodProc(stripchart,yticklines)    DrawYTicklines
+   set methodProc(stripchart,background)    BackgroundColour
+   set methodProc(stripchart,legendconfig)  LegendConfigure
+   set methodProc(stripchart,legend)        DrawLegend
+   set methodProc(stripchart,balloon)       DrawBalloon
    set methodProc(stripchart,balloonconfig) ConfigBalloon
-   set methodProc(stripchart,plaintext)  DrawPlainText
-   set methodProc(isometric,title)       DrawTitle
-   set methodProc(isometric,xtext)       DrawXtext
-   set methodProc(isometric,ytext)       DrawYtext
-   set methodProc(isometric,plot)        DrawIsometricData
-   set methodProc(isometric,saveplot)    SavePlot
-   set methodProc(isometric,background)  BackgroundColour
-   set methodProc(isometric,balloon)     DrawBalloon
-   set methodProc(isometric,balloonconfig) ConfigBalloon
-   set methodProc(isometric,plaintext)   DrawPlainText
-   set methodProc(3dplot,title)          DrawTitle
-   set methodProc(3dplot,plotfunc)       Draw3DFunction
-   set methodProc(3dplot,plotdata)       Draw3DData
-   set methodProc(3dplot,plotline)       Draw3DLineFrom3Dcoordinates
-   set methodProc(3dplot,gridsize)       GridSize3D
-   set methodProc(3dplot,saveplot)       SavePlot
-   set methodProc(3dplot,colour)         SetColours
-   set methodProc(3dplot,color)          SetColours
-   set methodProc(3dplot,xconfig)        XConfig
-   set methodProc(3dplot,yconfig)        YConfig
-   set methodProc(3dplot,zconfig)        ZConfig
-   set methodProc(3dplot,plotfuncont)    Draw3DFunctionContour
-   set methodProc(3dplot,background)     BackgroundColour
-   set methodProc(3dbars,title)          DrawTitle
-   set methodProc(3dbars,plot)           Draw3DBar
-   set methodProc(3dbars,yconfig)        YConfig
-   set methodProc(3dbars,saveplot)       SavePlot
-   set methodProc(3dbars,config)         Config3DBars
-   set methodProc(3dbars,balloon)        DrawBalloon
-   set methodProc(3dbars,balloonconfig)  ConfigBalloon
-   set methodProc(3dbars,plaintext)      DrawPlainText
-   set methodProc(radialchart,title)     DrawTitle
-   set methodProc(radialchart,plot)      DrawRadial
-   set methodProc(radialchart,saveplot)  SavePlot
-   set methodProc(radialchart,balloon)   DrawBalloon
-   set methodProc(radialchart,plaintext) DrawPlainText
-   set methodProc(txplot,title)          DrawTitle
-   set methodProc(txplot,xtext)          DrawXtext
-   set methodProc(txplot,ytext)          DrawYtext
-   set methodProc(txplot,plot)           DrawTimeData
-   set methodProc(txplot,interval)       DrawInterval
-   set methodProc(txplot,saveplot)       SavePlot
-   set methodProc(txplot,dataconfig)     DataConfig
-   set methodProc(txplot,xconfig)        XConfig
-   set methodProc(txplot,yconfig)        YConfig
-   set methodProc(txplot,xticklines)     DrawXTicklines
-   set methodProc(txplot,yticklines)     DrawYTicklines
-   set methodProc(txplot,background)     BackgroundColour
-   set methodProc(txplot,legendconfig)   LegendConfigure
-   set methodProc(txplot,legend)         DrawLegend
-   set methodProc(txplot,balloon)        DrawBalloon
-   set methodProc(txplot,balloonconfig)  ConfigBalloon
-   set methodProc(txplot,plaintext)      DrawPlainText
-   set methodProc(3dribbon,title)        DrawTitle
-   set methodProc(3dribbon,saveplot)     SavePlot
-   set methodProc(3dribbon,line)         Draw3DLine
-   set methodProc(3dribbon,area)         Draw3DArea
-   set methodProc(3dribbon,background)   BackgroundColour
+   set methodProc(stripchart,plaintext)     DrawPlainText
+   set methodProc(isometric,title)          DrawTitle
+   set methodProc(isometric,xtext)          DrawXtext
+   set methodProc(isometric,ytext)          DrawYtext
+   set methodProc(isometric,plot)           DrawIsometricData
+   set methodProc(isometric,saveplot)       SavePlot
+   set methodProc(isometric,background)     BackgroundColour
+   set methodProc(isometric,balloon)        DrawBalloon
+   set methodProc(isometric,balloonconfig)  ConfigBalloon
+   set methodProc(isometric,plaintext)      DrawPlainText
+   set methodProc(3dplot,title)             DrawTitle
+   set methodProc(3dplot,plotfunc)          Draw3DFunction
+   set methodProc(3dplot,plotdata)          Draw3DData
+   set methodProc(3dplot,plotline)          Draw3DLineFrom3Dcoordinates
+   set methodProc(3dplot,gridsize)          GridSize3D
+   set methodProc(3dplot,saveplot)          SavePlot
+   set methodProc(3dplot,colour)            SetColours
+   set methodProc(3dplot,color)             SetColours
+   set methodProc(3dplot,xconfig)           XConfig
+   set methodProc(3dplot,yconfig)           YConfig
+   set methodProc(3dplot,zconfig)           ZConfig
+   set methodProc(3dplot,plotfuncont)       Draw3DFunctionContour
+   set methodProc(3dplot,background)        BackgroundColour
+   set methodProc(3dbars,title)             DrawTitle
+   set methodProc(3dbars,plot)              Draw3DBar
+   set methodProc(3dbars,yconfig)           YConfig
+   set methodProc(3dbars,saveplot)          SavePlot
+   set methodProc(3dbars,config)            Config3DBars
+   set methodProc(3dbars,balloon)           DrawBalloon
+   set methodProc(3dbars,balloonconfig)     ConfigBalloon
+   set methodProc(3dbars,plaintext)         DrawPlainText
+   set methodProc(radialchart,title)        DrawTitle
+   set methodProc(radialchart,plot)         DrawRadial
+   set methodProc(radialchart,saveplot)     SavePlot
+   set methodProc(radialchart,balloon)      DrawBalloon
+   set methodProc(radialchart,plaintext)    DrawPlainText
+   set methodProc(txplot,title)             DrawTitle
+   set methodProc(txplot,xtext)             DrawXtext
+   set methodProc(txplot,ytext)             DrawYtext
+   set methodProc(txplot,plot)              DrawTimeData
+   set methodProc(txplot,interval)          DrawInterval
+   set methodProc(txplot,saveplot)          SavePlot
+   set methodProc(txplot,dataconfig)        DataConfig
+   set methodProc(txplot,xconfig)           XConfig
+   set methodProc(txplot,yconfig)           YConfig
+   set methodProc(txplot,xticklines)        DrawXTicklines
+   set methodProc(txplot,yticklines)        DrawYTicklines
+   set methodProc(txplot,background)        BackgroundColour
+   set methodProc(txplot,legendconfig)      LegendConfigure
+   set methodProc(txplot,legend)            DrawLegend
+   set methodProc(txplot,balloon)           DrawBalloon
+   set methodProc(txplot,balloonconfig)     ConfigBalloon
+   set methodProc(txplot,plaintext)         DrawPlainText
+   set methodProc(3dribbon,title)           DrawTitle
+   set methodProc(3dribbon,saveplot)        SavePlot
+   set methodProc(3dribbon,line)            Draw3DLine
+   set methodProc(3dribbon,area)            Draw3DArea
+   set methodProc(3dribbon,background)      BackgroundColour
 
    #
    # Auxiliary parameters
@@ -556,6 +581,7 @@ proc ::Plotchart::createXYPlot { w xscale yscale } {
 
    set newchart "xyplot_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler xyplot $w
+   CopyConfig xyplot $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
 
@@ -606,6 +632,7 @@ proc ::Plotchart::createStripchart { w xscale yscale } {
 
    set newchart "stripchart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler stripchart $w
+   CopyConfig stripchart $w
 
    return $newchart
 }
@@ -632,6 +659,7 @@ proc ::Plotchart::createIsometricPlot { w xscale yscale stepsize } {
 
    set newchart "isometric_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler isometric $w
+   CopyConfig isometric $w
 
    if { $stepsize != "noaxes" } {
       foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
@@ -665,6 +693,58 @@ proc ::Plotchart::createIsometricPlot { w xscale yscale stepsize } {
    return $newchart
 }
 
+# createXLogYPlot --
+#    Create a command for drawing an XY plot (with a vertical logarithmic axis)
+# Arguments:
+#    w           Name of the canvas
+#    xscale      Minimum, maximum and step for x-axis (initial)
+#    yscale      Minimum, maximum and step for y-axis (step is ignored!)
+# Result:
+#    Name of a new command
+# Note:
+#    The entire canvas will be dedicated to the XY plot.
+#    The plot will be drawn with axes
+#
+proc ::Plotchart::createXLogYPlot { w xscale yscale } {
+   variable data_series
+
+   foreach s [array names data_series "$w,*"] {
+      unset data_series($s)
+   }
+
+   set newchart "xlogyplot_$w"
+   interp alias {} $newchart {} ::Plotchart::PlotHandler xlogyplot $w
+   CopyConfig xlogyplot $w
+
+   foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
+
+   foreach {xmin xmax xdelt} $xscale {break}
+   foreach {ymin ymax ydelt} $yscale {break}
+
+   if { $xdelt == 0.0 || $ydelt == 0.0 } {
+      return -code error "Step size can not be zero"
+   }
+
+   if { $ymin <= 0.0 || $ymax <= 0.0 } {
+      return -code error "Minimum and maximum for y-axis must be positive"
+   }
+
+   #
+   # TODO: reversed log plot
+   #
+
+   viewPort         $w $pxmin $pymin $pxmax $pymax
+   worldCoordinates $w $xmin  [expr {log10($ymin)}]  $xmax [expr {log10($ymax)}]
+
+   DrawLogYaxis     $w $ymin  $ymax  $ydelt
+   DrawXaxis        $w $xmin  $xmax  $xdelt
+   DrawMask         $w
+   DefaultLegend    $w
+   DefaultBalloon   $w
+
+   return $newchart
+}
+
 # createHistogram --
 #    Create a command for drawing a histogram
 # Arguments:
@@ -687,6 +767,7 @@ proc ::Plotchart::createHistogram { w xscale yscale } {
 
    set newchart "histogram_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler histogram $w
+   CopyConfig histogram $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
 
@@ -734,6 +815,7 @@ proc ::Plotchart::createPiechart { w } {
 
    set newchart "piechart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler piechart $w
+   CopyConfig piechart $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsCircle $w] {break}
 
@@ -768,6 +850,7 @@ proc ::Plotchart::createPolarplot { w radius_data } {
 
    set newchart "polarplot_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler polarplot $w
+   CopyConfig polarplot $w
 
    set rad_max   [lindex $radius_data 0]
    set rad_step  [lindex $radius_data 1]
@@ -811,6 +894,7 @@ proc ::Plotchart::createBarchart { w xlabels yscale noseries } {
 
    set newchart "barchart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler vertbars $w
+   CopyConfig vertbars $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
 
@@ -856,6 +940,7 @@ proc ::Plotchart::createBarchart { w xlabels yscale noseries } {
 #
 proc ::Plotchart::createHorizontalBarchart { w xscale ylabels noseries } {
    variable data_series
+   variable config
 
    foreach s [array names data_series "$w,*"] {
       unset data_series($s)
@@ -863,6 +948,17 @@ proc ::Plotchart::createHorizontalBarchart { w xscale ylabels noseries } {
 
    set newchart "hbarchart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler horizbars $w
+   CopyConfig horizbars $w
+
+   set font      $config($w,leftaxis,font)
+   set xspacemax 0
+   foreach ylabel $ylabels {
+       set xspace [font measure $font $ylabel]
+       if { $xspace > $xspacemax } {
+           set xspacemax $xspace
+       }
+   }
+   set config($w,margin,left) [expr {$xspacemax+5}] ;# Slightly more space required!
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
 
@@ -916,6 +1012,7 @@ proc ::Plotchart::createTimechart { w time_begin time_end noitems } {
 
    set newchart "timechart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler timechart $w
+   CopyConfig timechart $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w 3] {break}
 
@@ -960,6 +1057,7 @@ proc ::Plotchart::createGanttchart { w time_begin time_end noitems
 
    set newchart "ganttchart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler ganttchart $w
+   CopyConfig ganttchart $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w 3 $text_width] {break}
 
@@ -1035,6 +1133,7 @@ proc ::Plotchart::create3DPlot { w xscale yscale zscale } {
 
    set newchart "3dplot_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler 3dplot $w
+   CopyConfig 3dplot $w
 
    foreach {pxmin pymin pxmax pymax} [Margins3DPlot $w] {break}
 
@@ -1075,6 +1174,7 @@ proc ::Plotchart::create3DBarchart { w yscale nobars } {
 
    set newchart "3dbarchart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler 3dbars $w
+   CopyConfig 3dbars $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w 4] {break}
 
@@ -1125,6 +1225,7 @@ proc ::Plotchart::createRadialchart { w names scale {style lines} } {
 
    set newchart "radialchart_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler radialchart $w
+   CopyConfig radialchart $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsCircle $w] {break}
 
@@ -1164,6 +1265,7 @@ proc ::Plotchart::createTXPlot { w tscale xscale } {
 
    set newchart "txplot_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler txplot $w
+   CopyConfig txplot $w
 
    foreach {pxmin pymin pxmax pymax} [MarginsRectangle $w] {break}
 
@@ -1231,6 +1333,7 @@ proc ::Plotchart::createRightAxis { w yscale } {
 
    interp alias {} $newchart {} ::Plotchart::PlotHandler $type r$w
    interp alias {} r$w       {} $w
+   CopyConfig $type r$w
 
    set xmin $scaling($w,xmin)
    set xmax $scaling($w,xmax)
@@ -1279,6 +1382,7 @@ proc ::Plotchart::create3DRibbonChart { w names yscale zscale } {
 
    set newchart "3dribbon_$w"
    interp alias {} $newchart {} ::Plotchart::PlotHandler 3dribbon $w
+   CopyConfig 3dribbon $w
 
    foreach {pxmin pymin pxmax pymax} [Margins3DPlot $w] {break}
 
@@ -1314,7 +1418,10 @@ source [file join [file dirname [info script]] "plotcontour.tcl"]
 source [file join [file dirname [info script]] "plotgantt.tcl"]
 source [file join [file dirname [info script]] "plotbusiness.tcl"]
 source [file join [file dirname [info script]] "plotannot.tcl"]
+source [file join [file dirname [info script]] "plotconfig.tcl"]
+source [file join [file dirname [info script]] "plotpack.tcl"]
+#source [file join [file dirname [info script]] "plotbind.tcl"]
 
 # Announce our presence
 #
-package provide Plotchart 1.3.1
+package provide Plotchart 1.5.1
