@@ -91,12 +91,17 @@ proc ::Plotchart::SavePlot { w filename args } {
 #    List of four values
 #
 proc ::Plotchart::MarginsRectangle { w {notext 2.0} {text_width 8}} {
+   variable config
    set pxmin [expr {10*$text_width}]
+   if { $pxmin < $config($w,margin,left) } {
+       set pxmin $config($w,margin,left)
+   }
    set pymin [expr {int(14*$notext)}]
-   set pxmax [expr {[WidthCanvas $w]  - 40}]
-   set pymax [expr {[HeightCanvas $w] - 30}]
-   #set pxmax [expr {[$w cget -width]  - 40}]
-   #set pymax [expr {[$w cget -height] - 30}]
+   if { $pymin < $config($w,margin,top) } {
+       set pymin $config($w,margin,top)
+   }
+   set pxmax [expr {[WidthCanvas $w]  - $config($w,margin,right)}]
+   set pymax [expr {[HeightCanvas $w] - $config($w,margin,bottom)}]
 
    return [list $pxmin $pymin $pxmax $pymax]
 }
@@ -327,12 +332,11 @@ proc ::Plotchart::PlotHandler { type w command args } {
 #
 proc ::Plotchart::DrawMask { w } {
    variable scaling
+   variable config
 
    set width  [expr {[WidthCanvas $w]  + 1}]
    set height [expr {[HeightCanvas $w] + 1}]
-   #set width  [expr {[$w cget -width]  + 1}]
-   #set height [expr {[$w cget -height] + 1}]
-   set colour [$w cget -background]
+   set colour $config($w,background,outercolor)
    set pxmin  $scaling($w,pxmin)
    set pxmax  $scaling($w,pxmax)
    set pymin  $scaling($w,pymin)
@@ -357,13 +361,15 @@ proc ::Plotchart::DrawMask { w } {
 #
 proc ::Plotchart::DrawTitle { w title } {
    variable scaling
+   variable config
 
    set width  [WidthCanvas $w]
    #set width  [$w cget -width]
    set pymin  $scaling($w,pymin)
 
    $w create text [expr {$width/2}] 3 -text $title \
-       -anchor n -tags title
+       -tags title -font $config($w,title,font) \
+       -fill $config($w,title,textcolor) -anchor $config($w,title,anchor)
 }
 
 # DrawData --
@@ -496,6 +502,23 @@ proc ::Plotchart::DrawStripData { w series xcrd ycrd } {
    DrawData $w $series $xcrd $ycrd
 }
 
+# DrawLogData --
+#    Draw the data in an X-logY-plot
+# Arguments:
+#    w           Name of the canvas
+#    series      Data series
+#    xcrd        Next x coordinate
+#    ycrd        Next y coordinate
+# Result:
+#    None
+# Side effects:
+#    New data drawn in canvas
+#
+proc ::Plotchart::DrawLogData { w series xcrd ycrd } {
+
+    DrawData $w $series $xcrd [expr {log10($ycrd)}]
+}
+
 # DrawInterval --
 #    Draw the data as an error interval in an XY-plot
 # Arguments:
@@ -751,12 +774,13 @@ proc ::Plotchart::DrawPolarData { w series rad phi } {
 #    series      Data series
 #    ydata       Series of y data
 #    colour      The colour to use (optional)
+#    dir         Direction if graded colours are used (see DrawGradientBackground)
 # Result:
 #    None
 # Side effects:
 #    Data bars drawn in canvas
 #
-proc ::Plotchart::DrawVertBarData { w series ydata {colour black}} {
+proc ::Plotchart::DrawVertBarData { w series ydata {colour black} {dir {}} } {
    variable data_series
    variable scaling
    variable legend
@@ -804,8 +828,13 @@ proc ::Plotchart::DrawVertBarData { w series ydata {colour black}} {
       set y     [expr {$yvalue+$ybase}]
       foreach {px1 py1} [coordsToPixel $w $x     $ybase] {break}
       foreach {px2 py2} [coordsToPixel $w $xnext $y    ] {break}
-      $w create rectangle $px1 $py1 $px2 $py2 \
-                     -fill $colour -tag data
+
+      if { $dir == {} } {
+          $w create rectangle $px1 $py1 $px2 $py2 \
+                         -fill $colour -tag data
+      } else {
+          DrawGradientBackground $w $colour $dir [list $px1 $py1 $px2 $py2]
+      }
       $w lower data
 
       set x [expr {$x+1.0}]
@@ -830,12 +859,13 @@ proc ::Plotchart::DrawVertBarData { w series ydata {colour black}} {
 #    series      Data series
 #    xdata       Series of x data
 #    colour      The colour to use (optional)
+#    dir         Direction if graded colours are used (see DrawGradientBackground)
 # Result:
 #    None
 # Side effects:
 #    Data bars drawn in canvas
 #
-proc ::Plotchart::DrawHorizBarData { w series xdata {colour black}} {
+proc ::Plotchart::DrawHorizBarData { w series xdata {colour black} {dir {}} } {
    variable data_series
    variable scaling
 
@@ -881,8 +911,14 @@ proc ::Plotchart::DrawHorizBarData { w series xdata {colour black}} {
       set x     [expr {$xvalue+$xbase}]
       foreach {px1 py1} [coordsToPixel $w $xbase $y    ] {break}
       foreach {px2 py2} [coordsToPixel $w $x     $ynext] {break}
-      $w create rectangle $px1 $py1 $px2 $py2 \
-                     -fill $colour -tag data
+
+      if { $dir == {} } {
+          $w create rectangle $px1 $py1 $px2 $py2 \
+                         -fill $colour -tag data
+      } else {
+          DrawGradientBackground $w $colour $dir [list $px1 $py1 $px2 $py2]
+      }
+
       $w lower data
 
       set y [expr {$y+1.0}]
